Subsetting: Select an scdf case by name

$.scdfR Documentation

Select an scdf case by name

Description

Selects a single case from a scdf object by its name.

Usage

## S3 method for class 'scdf'
x$i

## S3 method for class 'scdf'
x[i]

Arguments

x

A scdf object.

i

A case name from x. If i is not a name of x, a warning is issued.

Value

A scdf object containing only the selected case.

Author(s)

Juergen Wilbert


scan documentation built on April 1, 2026, 9:06 a.m.