abort: Throws an error

View source: R/message-system.R

abortR Documentation

Throws an error

Description

This is a convenience wrapper for internal use.

Usage

abort(..., class = NULL, call = FALSE)

Arguments

...

The message. This can be a character string or a combination of character strings and variables.

class

An optional class or vector of classes to add to the error.

call

If TRUE, the call will be included in the error message. Default is FALSE.


scan documentation built on April 28, 2026, 9:06 a.m.