| .inheritParams | R Documentation |
This function is only used to inherit parameter descriptions in the documentation of other functions. It has no other purpose and is not meant to be called directly.
.inheritParams(
data,
scdf,
dvar,
mvar,
pvar,
decreasing,
phases,
model,
contrast,
contrast_level,
contrast_slope,
trend,
level,
slope,
nice,
...
)
data |
A single-case data frame. See |
scdf |
A single-case data frame. See |
dvar |
Character string with the name of the dependent variable. Defaults to the attributes in the scdf file. |
mvar |
Character string with the name of the measurement time variable. Defaults to the attributes in the scdf file. |
pvar |
Character string with the name of the phase variable. Defaults to the attributes in the scdf file. |
decreasing |
If you expect data to be lower in the B phase, set
|
phases |
A vector of two characters or numbers indicating the two phases
that should be compared. E.g., |
model |
Model used for calculating the dummy parameters (see Huitema &
McKean, 2000). Default is |
contrast |
Sets contrast_level and contrast_slope. Either "first", "preceding" or a contrast matrix. If NA contrast is ignored. |
contrast_level |
Either "first", "preceding" or a contrast matrix. If NA contrast_level is a copy of contrast. |
contrast_slope |
Either "first", "preceding" or a contrast matrix. If NA contrast_level is a copy of contrast. |
trend |
A logical indicating if a trend parameters is included in the model. |
level |
A logical indicating if a level parameters is included in the model. |
slope |
A logical indicating if a slope parameters is included in the model. |
nice |
If set TRUE (default) output values are rounded and optimized for publication tables. |
... |
Further arguments passed to the function. |
No return value.
Juergen Wilbert
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.