This function returns the percentage of non-overlapping data. Due to its
error-proneness the PND should not be used, but nap or
pand instead (see Parker & Vannest, 2009).
Usage
pnd(data, dvar, pvar, decreasing = FALSE, phases = c(1, 2))Arguments
- data
A single-case data frame. See
scdf()to learn about this format.- dvar
Character string with the name of the dependent variable. Defaults to the attributes in the scdf file.
- pvar
Character string with the name of the phase variable. Defaults to the attributes in the scdf file.
- decreasing
If you expect data to be lower in the B phase, set
decreasing = TRUE. Default isdecreasing = FALSE.- phases
A vector of two characters or numbers indicating the two phases that should be compared. E.g.,
phases = c("A","C")orphases = c(2,4)for comparing the second to the fourth phase. Phases could be combined by providing a list with two elements. E.g.,phases = list(A = c(1,3), B = c(2,4))will compare phases 1 and 3 (as A) against 2 and 4 (as B). Default isphases = c(1,2).
Details
PND is calculated by determining the number of data points in phase B that exceed the highest data point in phase A (or are lower than the lowest data point in phase A for decreasing data) divided by the total number of data points in phase B. This value is then multiplied by 100 to get a percentage value.
See also
Other overlap functions:
ird(),
nap(),
overlap(),
pand(),
pem(),
pet(),
print.sc_cdc(),
select_phases(),
tau_u()