| sample_names | R Documentation |
Generates random names for cases. Names are sampled from a predefined list of neutral, male, female, or mixed names.
sample_names(n = 1, type = "neutral", seed = NULL)
n |
Number of names to sample. |
type |
"neutral", "male", "female", or "mixed" type of names to sample. |
seed |
A seed for the random number generator. If provided, the sampling will be reproducible. |
This function is useful for anonymizing case names in datasets or for generating random identifiers.
A character vector with random names.
sample_names(3)
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.