| summary.scdf | R Documentation |
Provides a summary of an scdf object, including the number of cases,
measurements per case, and design information.
## S3 method for class 'scdf'
summary(object, all_cases = FALSE, ...)
object |
scdf |
all_cases |
IF TRUE, more that 10 cases are summarized |
... |
not in use |
The summary includes:
Total number of cases in the scdf.
A table listing each case with the number of measurements and design.
Variable names with annotations for phase, measurement-time, and dependent variable.
Additional information and author details if available.
Juergen Wilbert
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.