| $.scdf | R Documentation |
Selects a single case from a scdf object by its name.
## S3 method for class 'scdf'
x$i
## S3 method for class 'scdf'
x[i]
x |
A scdf object. |
i |
A case name from x. If i is not a name of x, a warning is issued. |
A scdf object containing only the selected case.
Juergen Wilbert
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.