View source: R/message-system.R
| abort | R Documentation |
This is a convenience wrapper for internal use.
abort(..., class = NULL, call = FALSE)
... |
The message. This can be a character string or a combination of character strings and variables. |
class |
An optional class or vector of classes to add to the error. |
call |
If TRUE, the call will be included in the error message. Default is FALSE. |
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.