| batch_apply | R Documentation |
This function applies a given function to each case of a multiple case scdf, returning a list of the output of each function call.
batch_apply(scdf, fn, simplify = FALSE)
scdf |
A list of inputs to apply the function to. |
fn |
The function to apply to each element. Use a |
simplify |
If simplify is TRUE and |
If simplify is TRUE and the function returns a vector of values, the output
is combined into a data frame with case names as additional columns.
This is particularly useful for applying statistical models or summary statistics to each case in an scdf.
A list of the output of each function call.
Juergen Wilbert
Other data manipulation functions:
add_l2(),
as.data.frame.scdf(),
as_scdf(),
fill_missing(),
moving_median(),
print.sc_outlier(),
ranks(),
rescale(),
scdf(),
select_cases(),
set_vars(),
shift(),
smooth_cases(),
standardize(),
truncate_phase()
batch_apply(exampleAB, coef(plm(.)))
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.