Export creates html files of tables or displays them directly in the viewer pane of rstudio. When applied in rmarkdown/quarto, tables can also be created for pdf/latex output.
export(object, ...)# S3 method for sc_desc
export(
object,
caption = NA,
footnote = NA,
filename = NA,
kable_styling_options = list(),
kable_options = list(),
flip = FALSE,
...
)
# S3 method for sc_nap
export(
object,
caption = NA,
footnote = NA,
filename = NA,
kable_styling_options = list(),
kable_options = list(),
round = 2,
...
)
# S3 method for sc_overlap
export(
object,
caption = NA,
footnote = NULL,
filename = NA,
kable_styling_options = list(),
kable_options = list(),
round = 2,
flip = FALSE,
...
)
# S3 method for sc_pem
export(
object,
caption = NA,
footnote = NA,
filename = NA,
kable_styling_options = list(),
kable_options = list(),
round = 2,
...
)
# S3 method for sc_plm
export(
object,
caption = NA,
footnote = NA,
filename = NA,
kable_styling_options = list(),
kable_options = list(),
round = 2,
nice = TRUE,
...
)
# S3 method for sc_power
export(
object,
caption = NA,
footnote = NA,
filename = NA,
kable_styling_options = list(),
kable_options = list(),
...
)
# S3 method for sc_smd
export(
object,
caption = NA,
footnote = NA,
filename = NA,
select = c("Case", `Mean A` = "mA", `Mean B` = "mB", `SD A` = "sdA", `SD B` = "sdB",
`SD Cohen` = "sd cohen", `SD Hedges` = "sd hedges", "Glass' delta", "Hedges' g",
"Hedges' g correction", "Hedges' g durlak correction", "Cohen's d"),
kable_styling_options = list(),
kable_options = list(),
round = 2,
flip = FALSE,
...
)
# S3 method for sc_trend
export(
object,
caption = NA,
footnote = NA,
filename = NA,
kable_styling_options = list(),
kable_options = list(),
round = 2,
...
)
# S3 method for scdf
export(
object,
caption = NA,
footnote = NA,
filename = NA,
kable_styling_options = list(),
kable_options = list(),
cols,
...
)
Returns or displays a specially formatted html (or latex) file.
An scdf or an object exported from a scan function.
Further Arguments passed to internal functions.
Character string with table caption. If left NA (default) a caption will be created based on the exported object.
Character string with table footnote. If left NA (default) a footnote will be created based on the exported object.
String containing the file name. If a filename is given the output will be written to that file.
list with arguments passed to the kable_styling function.
list with arguments passed to the kable function.
If TRUE, some objects are exported with rows and columns flipped.
Integer passed to the digits argument internally used to round values.
If set TRUE (default) output values are rounded and optimized for publication tables.
A character vector containing the names of the variables to be included. If the vector is named, the variables will be renamed accordingly.
Defines which columns are included when exporting an scdf. It is either a vector of variable names or the string "main" will select the central variables.