fetch: Fetches elements from scan objects

fetchR Documentation

Fetches elements from scan objects

Description

The fetch function is a getter function for scan objects returned from regression functions such as plm(), hplm(), bplm(), and mplm(). It allows users to extract specific elements from these objects, such as the fitted model.

Usage

fetch(object, what, ...)

Arguments

object

Object returned from a scan function.

what

Element/part to be extracted. Currently, only "model" is supported to extract the fitted regression model.

...

Further parameters passed to the function.

Value

An object of the respective regression model class.

Author(s)

Juergen Wilbert

See Also

Other regression functions: bplm(), hplm(), mplm(), plm(), print.sc_ac(), print.sc_bctau(), trend()

Examples

# plm regression
model1 <- plm(example_A24)
fetch(model1, what = "model") |> summary()
# Multilevel plm regression
model2 <- hplm(exampleAB_50)
fetch(model2, what = "model") |> summary()
# Bayesian plm regression
model3 <- bplm(exampleAB_50, nitt = 5000)
fetch(model3, what = "model") |> summary()

scan documentation built on April 1, 2026, 9:06 a.m.