| fetch | R Documentation |
The fetch function is a getter function for scan objects
returned from regression functions such as plm(), hplm(), bplm(), and
mplm(). It allows users to extract specific elements from these objects,
such as the fitted model.
fetch(object, what, ...)
object |
Object returned from a scan function. |
what |
Element/part to be extracted. Currently, only "model" is supported to extract the fitted regression model. |
... |
Further parameters passed to the function. |
An object of the respective regression model class.
Juergen Wilbert
Other regression functions:
bplm(),
hplm(),
mplm(),
plm(),
print.sc_ac(),
print.sc_bctau(),
trend()
# plm regression
model1 <- plm(example_A24)
fetch(model1, what = "model") |> summary()
# Multilevel plm regression
model2 <- hplm(exampleAB_50)
fetch(model2, what = "model") |> summary()
# Bayesian plm regression
model3 <- bplm(exampleAB_50, nitt = 5000)
fetch(model3, what = "model") |> summary()
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.