Provides a summary of an scdf object, including the number of cases,
measurements per case, and design information.
Usage
# S3 method for class 'scdf'
summary(object, all_cases = FALSE, ...)Provides a summary of an scdf object, including the number of cases,
measurements per case, and design information.
# S3 method for class 'scdf'
summary(object, all_cases = FALSE, ...)